( cd usr/lib ; rm -rf libdrm_omap.so )
( cd usr/lib ; ln -sf libdrm_omap.so.1.0.0 libdrm_omap.so )
( cd usr/lib ; rm -rf libdrm.so.2 )
( cd usr/lib ; ln -sf libdrm.so.2.4.0 libdrm.so.2 )
( cd usr/lib ; rm -rf libdrm_exynos.so )
( cd usr/lib ; ln -sf libdrm_exynos.so.1.0.0 libdrm_exynos.so )
( cd usr/lib ; rm -rf libdrm_nouveau.so )
( cd usr/lib ; ln -sf libdrm_nouveau.so.2.0.0 libdrm_nouveau.so )
( cd usr/lib ; rm -rf libdrm_nouveau.so.2 )
( cd usr/lib ; ln -sf libdrm_nouveau.so.2.0.0 libdrm_nouveau.so.2 )
( cd usr/lib ; rm -rf libdrm_exynos.so.1 )
( cd usr/lib ; ln -sf libdrm_exynos.so.1.0.0 libdrm_exynos.so.1 )
( cd usr/lib ; rm -rf libdrm_radeon.so.1 )
( cd usr/lib ; ln -sf libdrm_radeon.so.1.0.1 libdrm_radeon.so.1 )
( cd usr/lib ; rm -rf libdrm_omap.so.1 )
( cd usr/lib ; ln -sf libdrm_omap.so.1.0.0 libdrm_omap.so.1 )
( cd usr/lib ; rm -rf libkms.so.1 )
( cd usr/lib ; ln -sf libkms.so.1.0.0 libkms.so.1 )
( cd usr/lib ; rm -rf libkms.so )
( cd usr/lib ; ln -sf libkms.so.1.0.0 libkms.so )
( cd usr/lib ; rm -rf libdrm_radeon.so )
( cd usr/lib ; ln -sf libdrm_radeon.so.1.0.1 libdrm_radeon.so )
( cd usr/lib ; rm -rf libdrm.so )
( cd usr/lib ; ln -sf libdrm.so.2.4.0 libdrm.so )
